#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A demonstration for common string manipulation actions.
    /// </summary>
    [Description("A demonstration for common string manipulation actions.")]
    public class SampleStringFunctions : Indicator
    {
        #region Variables
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            CalculateOnBarClose	= true;
            Overlay				= false;
            PriceTypeSupported	= false;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {			
        	if (CurrentBar == 0)
			{				
				// This command clears all data from the output window.
				ClearOutputWindow();
				
				// This command will just print a blank line in the output window.
				Print("");
			
				
				/* C# requires certain characters to be "escaped". An escape character is used to tell a computer program
				   the character following it has a different meaning than usual. For example, if you wanted to print quotes in a string, you couldn't do:
				   Print("Joe said, "Hey Bob!""); because when the program reached the second ", it would read that as the end of the string and give an error.
				   Instead, you would escape the double quotes with a backslash "\" like this: Print("Joe said, \"Hey Bob!\"");
				   In the example below, \ is a character that needs an escape character preceding it, resulting in \\.
				   Another option would be to specify the string as literal, with the @ sign-useful for specifying directories.
				   The two strings below will print the exact same output. */
				string directory = @"C:\NinjaTrader 6.5\bin";
				string directory2 = "C:\\NinjaTrader 6.5\\bin";
				Print(directory);
				Print(directory2);
				
				
				// Print another blank line
				Print("");
				
				
				// Split a string at each space using the following string.
				string s = "NinjaTrader is a trading platform.";
				
				// To define a single character, it is necessary to use single quotes (') instead of double quotes (").
				char aSpace = ' ';
				
				// Create a string array and fill it with the words that come from from splitting string s at each space.
				string[] words = s.Split(aSpace);
				
				// Print each element (word) from the array (words).
				foreach (string word in words)
					Print(word);
				
				
				// Print another blank line
				Print("");

				
				// Finding a string
				Print("Find the position of \"needle\" in the phrase: \"Like finding a needle in a haystack.\"");
				string phrase = "Like finding a needle in a haystack.";
				string whatToFind = "needle";
				
				// string.IndexOf will return the position of the string by character. This example will return 15 because "needle" starts at the 15th character in the string.
				int idx = phrase.IndexOf(whatToFind);
				Print("Index of \"needle\": "  + idx);

				
				// Replacing a string, we'll use the phrase above "Like finding a needle in a haystack."
				Print("");
				Print("From the phrase above, replace \"haystack\" with \"some big field\".");
				
				// string.Replace takes the string to find as the first argument and the string to replace with as the second argument.
				phrase = phrase.Replace("haystack", "some big field");
				Print(phrase);
			}
        }
        #region Properties
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private SampleStringFunctions[] cacheSampleStringFunctions = null;

        private static SampleStringFunctions checkSampleStringFunctions = new SampleStringFunctions();

        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        public SampleStringFunctions SampleStringFunctions()
        {
            return SampleStringFunctions(Input);
        }

        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        public SampleStringFunctions SampleStringFunctions(Data.IDataSeries input)
        {

            if (cacheSampleStringFunctions != null)
                for (int idx = 0; idx < cacheSampleStringFunctions.Length; idx++)
                    if (cacheSampleStringFunctions[idx].EqualsInput(input))
                        return cacheSampleStringFunctions[idx];

            SampleStringFunctions indicator = new SampleStringFunctions();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.SetUp();

            SampleStringFunctions[] tmp = new SampleStringFunctions[cacheSampleStringFunctions == null ? 1 : cacheSampleStringFunctions.Length + 1];
            if (cacheSampleStringFunctions != null)
                cacheSampleStringFunctions.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheSampleStringFunctions = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleStringFunctions SampleStringFunctions()
        {
            return _indicator.SampleStringFunctions(Input);
        }

        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleStringFunctions SampleStringFunctions(Data.IDataSeries input)
        {
            return _indicator.SampleStringFunctions(input);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.SampleStringFunctions SampleStringFunctions()
        {
            return _indicator.SampleStringFunctions(Input);
        }

        /// <summary>
        /// A demonstration for common string manipulation actions.
        /// </summary>
        /// <returns></returns>
        public Indicator.SampleStringFunctions SampleStringFunctions(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.SampleStringFunctions(input);
        }

    }
}
#endregion
